@@ -131,6 +131,16 @@ sub characters {
                    endash => "-",
                    dash =>    "\x{2013}",
                   },
+            id => {
+                   ldouble => "\x{201c}",
+                   rdouble => "\x{201d}",
+                   lsingle => "\x{2018}",
+                   rsingle => "\x{2019}",
+                   apos =>    "\x{2019}",
+                   emdash =>  "\x{2013}", # en dash –
+                   endash =>  "\x{2013}", # en dash –
+                   dash =>    "\x{2013}",
+                  },
             nl => {
                    ldouble => "\x{201c}",
                    rdouble => "\x{201d}",
